import json
import os
from typing import Any, Optional

from llama_index.embeddings.base import BaseEmbedding
from llama_index.embeddings.huggingface import HuggingFaceEmbedding
from unstract.adapters.embedding.embedding_adapter import EmbeddingAdapter
from unstract.adapters.embedding.helper import EmbeddingHelper
from unstract.adapters.exceptions import AdapterError


class Constants:
    ADAPTER_NAME = "adapter_name"
    MODEL = "model_name"
    TOKENIZER_NAME = "tokenizer_name"
    MAX_LENGTH = "max_length"
    NORMALIZE = "normalize"


class HuggingFace(EmbeddingAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("HuggingFace")
        self.config = settings
        self.json_credentials = json.loads(
            settings.get("json_credentials", "{}")
        )

    @staticmethod
    def get_id() -> str:
        return "huggingface|90ec9ec2-1768-4d69-8fb1-c88b95de5e5a"

    @staticmethod
    def get_name() -> str:
        return "HuggingFace"

    @staticmethod
    def get_description() -> str:
        return "HuggingFace LLM"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/huggingface.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def get_embedding_instance(self) -> Optional[BaseEmbedding]:
        try:
            embedding_batch_size = EmbeddingHelper.get_embedding_batch_size(
                config=self.config
            )
            if (self.config.get(Constants.MAX_LENGTH)) is not None:
                embedding = HuggingFaceEmbedding(
                    model_name=str(self.config.get(Constants.MODEL)),
                    tokenizer_name=str(
                        self.config.get(Constants.TOKENIZER_NAME)
                    ),
                    normalize=bool(self.config.get(Constants.NORMALIZE)),
                    embed_batch_size=embedding_batch_size,
                    max_length=int(self.config.get(Constants.MAX_LENGTH, 10)),
                )
            else:
                embedding = HuggingFaceEmbedding(
                    model_name=str(self.config.get(Constants.MODEL)),
                    tokenizer_name=str(
                        self.config.get(Constants.TOKENIZER_NAME)
                    ),
                    normalize=bool(self.config.get(Constants.NORMALIZE)),
                    embed_batch_size=embedding_batch_size,
                )
            return embedding
        except Exception as e:
            raise AdapterError(str(e))

    def test_connection(self) -> bool:
        embedding = self.get_embedding_instance()
        test_result: bool = EmbeddingHelper.test_embedding_instance(embedding)
        return test_result



import json
import os
from typing import Any, Optional

from google.auth.transport import requests as google_requests
from google.oauth2 import service_account
from llama_index.llms.llm import LLM
from llama_index.llms.vertex import Vertex
from unstract.adapters.llm.helper import LLMHelper
from unstract.adapters.llm.llm_adapter import LLMAdapter


class Constants:
    MODEL = "model"
    PROJECT = "project"
    JSON_CREDENTIALS = "json_credentials"


class VertexAILLM(LLMAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("VertexAILLM")
        self.config = settings

    @staticmethod
    def get_id() -> str:
        return "vertexai|78fa17a5-a619-47d4-ac6e-3fc1698fdb55"

    @staticmethod
    def get_name() -> str:
        return "VertexAI"

    @staticmethod
    def get_description() -> str:
        return "Vertex Gemini LLM"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/VertexAI.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def get_llm_instance(self) -> Optional[LLM]:
        input_credentials = self.config.get(Constants.JSON_CREDENTIALS)
        if not input_credentials:
            input_credentials = "{}"
        json_credentials = json.loads(input_credentials)
        credentials = service_account.Credentials.from_service_account_info(
            info=json_credentials,
            scopes=["https://www.googleapis.com/auth/cloud-platform"],
        )
        credentials.refresh(google_requests.Request())
        llm = Vertex(
            project=str(self.config.get(Constants.PROJECT)),
            model=str(self.config.get(Constants.MODEL)),
            credentials=credentials,
            temperature=0,
            additional_kwargs={},
        )
        return llm

    def test_connection(self) -> bool:
        llm = self.get_llm_instance()
        test_result: bool = LLMHelper.test_llm_instance(llm=llm)
        return test_result



__version__ = "0.7.1"

import logging
from logging import NullHandler
from typing import Any

logging.getLogger(__name__).addHandler(NullHandler())

AdapterDict = dict[str, dict[str, Any]]


def get_adapter_version() -> str:
    """Returns the adapter package's version."""
    return __version__



import os
from typing import Any, Optional

import psycopg2
from llama_index.vector_stores import PGVectorStore
from llama_index.vector_stores.types import BasePydanticVectorStore
from psycopg2._psycopg import connection
from unstract.adapters.exceptions import AdapterError
from unstract.adapters.vectordb.constants import VectorDbConstants
from unstract.adapters.vectordb.helper import VectorDBHelper
from unstract.adapters.vectordb.vectordb_adapter import VectorDBAdapter


class Constants:
    DATABASE = "database"
    HOST = "host"
    PASSWORD = "password"
    PORT = "port"
    USER = "user"
    SCHEMA = "schema"


class Postgres(VectorDBAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("Postgres")
        self.config = settings
        self.client: Optional[connection] = None
        self.collection_name: str = VectorDbConstants.DEFAULT_VECTOR_DB_NAME
        self.schema_name: str = VectorDbConstants.DEFAULT_VECTOR_DB_NAME

    @staticmethod
    def get_id() -> str:
        return "postgres|70ab6cc2-e86a-4e5a-896f-498a95022d34"

    @staticmethod
    def get_name() -> str:
        return "Postgres"

    @staticmethod
    def get_description() -> str:
        return "Postgres VectorDB"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/postgres.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def get_vector_db_instance(self) -> Optional[BasePydanticVectorStore]:
        try:
            self.collection_name = VectorDBHelper.get_collection_name(
                self.config.get(VectorDbConstants.VECTOR_DB_NAME),
                self.config.get(VectorDbConstants.EMBEDDING_DIMENSION),
            )
            self.schema_name = self.config.get(
                Constants.SCHEMA,
                VectorDbConstants.DEFAULT_VECTOR_DB_NAME,
            )
            dimension = self.config.get(
                VectorDbConstants.EMBEDDING_DIMENSION,
                VectorDbConstants.DEFAULT_EMBEDDING_SIZE,
            )
            vector_db = PGVectorStore.from_params(
                database=self.config.get(Constants.DATABASE),
                schema_name=self.schema_name,
                host=self.config.get(Constants.HOST),
                password=self.config.get(Constants.PASSWORD),
                port=str(self.config.get(Constants.PORT)),
                user=self.config.get(Constants.USER),
                table_name=self.collection_name,
                embed_dim=dimension,
            )
            self.client = psycopg2.connect(
                database=self.config.get(Constants.DATABASE),
                host=self.config.get(Constants.HOST),
                user=self.config.get(Constants.USER),
                password=self.config.get(Constants.PASSWORD),
                port=str(self.config.get(Constants.PORT)),
            )

            return vector_db
        except Exception as e:
            raise AdapterError(str(e))

    def test_connection(self) -> bool:
        self.config[
            VectorDbConstants.EMBEDDING_DIMENSION
        ] = VectorDbConstants.TEST_CONNECTION_EMBEDDING_SIZE
        vector_db = self.get_vector_db_instance()
        test_result: bool = VectorDBHelper.test_vector_db_instance(
            vector_store=vector_db
        )

        # Delete the collection that was created for testing
        if self.client is not None:
            self.client.cursor().execute(
                f"DROP TABLE IF EXISTS "
                f"{self.schema_name}.data_{self.collection_name} CASCADE"
            )
            self.client.cursor().execute(
                f"DROP SCHEMA IF EXISTS {self.schema_name} CASCADE"
            )
            self.client.commit()

        return test_result



import logging
import os
from typing import Any, Optional

from unstract.adapters.x2text.helper import UnstructuredHelper
from unstract.adapters.x2text.x2text_adapter import X2TextAdapter

logger = logging.getLogger(__name__)


class UnstructuredCommunity(X2TextAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("UnstructuredIOCommunity")
        self.config = settings

    @staticmethod
    def get_id() -> str:
        return "unstructuredcommunity|eeed506f-1875-457f-9101-846fc7115676"

    @staticmethod
    def get_name() -> str:
        return "Unstructured IO Community"

    @staticmethod
    def get_description() -> str:
        return "Unstructured IO Community X2Text"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/UnstructuredIO.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def process(
        self,
        input_file_path: str,
        output_file_path: Optional[str] = None,
        **kwargs: dict[Any, Any],
    ) -> str:
        try:
            output: str = UnstructuredHelper.process_document(
                self.config, input_file_path, output_file_path
            )
            return output
        except Exception as e:
            logger.error(
                f"Error occured while "
                f"unstructured IO Community process document {e}"
            )
            raise e

    def test_connection(self) -> bool:
        try:
            result: bool = UnstructuredHelper.test_server_connection(
                self.config
            )
            return result
        except Exception as e:
            logger.error(
                f"Error occured while testing "
                f"unstructured IO Community adapter {e}"
            )
            raise e



import os
from typing import Any, Optional

from llama_index.vector_stores import MilvusVectorStore
from llama_index.vector_stores.types import VectorStore
from pymilvus import MilvusClient

from unstract.adapters.exceptions import AdapterError
from unstract.adapters.vectordb.constants import VectorDbConstants
from unstract.adapters.vectordb.helper import VectorDBHelper
from unstract.adapters.vectordb.vectordb_adapter import VectorDBAdapter


class Constants:
    URI = "uri"
    TOKEN = "token"
    DIM_VALUE = 1536


class Milvus(VectorDBAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("Milvus")
        self.config = settings
        self.client: Optional[MilvusClient] = None
        self.collection_name: str = VectorDbConstants.DEFAULT_VECTOR_DB_NAME

    @staticmethod
    def get_id() -> str:
        return "milvus|3f42f6f9-4b8e-4546-95f3-22ecc9aca442"

    @staticmethod
    def get_name() -> str:
        return "Milvus"

    @staticmethod
    def get_description() -> str:
        return "Milvus VectorDB"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/Milvus.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def get_vector_db_instance(self) -> Optional[VectorStore]:
        try:
            self.collection_name = VectorDBHelper.get_collection_name(
                self.config.get(VectorDbConstants.VECTOR_DB_NAME),
                self.config.get(VectorDbConstants.EMBEDDING_DIMENSION),
            )
            dimension = self.config.get(
                VectorDbConstants.EMBEDDING_DIMENSION,
                VectorDbConstants.DEFAULT_EMBEDDING_SIZE,
            )
            vector_db = MilvusVectorStore(
                uri=self.config.get(Constants.URI, ""),
                collection_name=self.collection_name,
                token=self.config.get(Constants.TOKEN, ""),
                dim=dimension,
            )
            self.client = vector_db.client
            return vector_db
        except Exception as e:
            raise AdapterError(str(e))

    def test_connection(self) -> bool:
        self.config[
            VectorDbConstants.EMBEDDING_DIMENSION
        ] = VectorDbConstants.TEST_CONNECTION_EMBEDDING_SIZE
        vector_db = self.get_vector_db_instance()
        test_result: bool = VectorDBHelper.test_vector_db_instance(
            vector_store=vector_db
        )
        # Delete the collection that was created for testing
        if self.client is not None:
            self.client.drop_collection(self.collection_name)
        return test_result



from enum import Enum


class ProcessingModes(Enum):
    OCR = "ocr"
    TEXT = "text"


class OutputModes(Enum):
    LINE_PRINTER = "line-printer"
    DUMP_TEXT = "dump-text"
    TEXT = "text"


class HTTPMethod(Enum):
    GET = "GET"
    POST = "POST"


class WhispererHeader:
    UNSTRACT_KEY = "unstract-key"


class WhispererEndpoint:
    """Endpoints available at LLMWhisperer service."""

    TEST_CONNECTION = "test-connection"
    WHISPER = "whisper"


class WhispererConfig:
    """Dictionary keys used to configure LLMWhisperer service."""

    URL = "url"
    PROCESSING_MODE = "processing_mode"
    OUTPUT_MODE = "output_mode"
    UNSTRACT_KEY = "unstract_key"
    MEDIAN_FILTER_SIZE = "median_filter_size"
    GAUSSIAN_BLUR_RADIUS = "gaussian_blur_radius"
    FORCE_TEXT_PROCESSING = "force_text_processing"


class WhispererDefaults:
    """Defaults meant for OCR mode."""

    MEDIAN_FILTER_SIZE = 0
    GAUSSIAN_BLUR_RADIUS = 0.0
    FORCE_TEXT_PROCESSING = False



from requests import Response
from requests.exceptions import RequestException

from unstract.adapters.constants import Common


class AdapterUtils:
    @staticmethod
    def get_msg_from_request_exc(
        err: RequestException,
        message_key: str,
        default_err: str = Common.DEFAULT_ERR_MESSAGE,
    ) -> str:
        """Gets the message from the RequestException.

        Args:
            err_response (Response): Error response from the exception
            message_key (str): Key from response containing error message

        Returns:
            str: Error message returned by the server
        """
        if hasattr(err, "response"):
            err_response: Response = err.response  # type: ignore
            if err_response.headers["Content-Type"] == "application/json":
                err_json = err_response.json()
                if message_key in err_json:
                    return str(err_json[message_key])
            elif err_response.headers["Content-Type"] == "text/plain":
                return err.response.text()  # type: ignore
        return default_err



import logging
import os
from typing import Any, Optional

from llama_index.vector_stores.qdrant import QdrantVectorStore
from llama_index.vector_stores.types import BasePydanticVectorStore
from qdrant_client import QdrantClient
from unstract.adapters.exceptions import AdapterError
from unstract.adapters.vectordb.constants import VectorDbConstants
from unstract.adapters.vectordb.helper import VectorDBHelper
from unstract.adapters.vectordb.vectordb_adapter import VectorDBAdapter

logger = logging.getLogger(__name__)


class Constants:
    URL = "url"
    API_KEY = "api_key"


class Qdrant(VectorDBAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("Qdrant")
        self.config = settings
        self.client: Optional[QdrantClient] = None
        self.collection_name: str = VectorDbConstants.DEFAULT_VECTOR_DB_NAME

    @staticmethod
    def get_id() -> str:
        return "qdrant|41f64fda-2e4c-4365-89fd-9ce91bee74d0"

    @staticmethod
    def get_name() -> str:
        return "Qdrant"

    @staticmethod
    def get_description() -> str:
        return "Qdrant LLM"

    @staticmethod
    def get_icon() -> str:
        return (
            "/icons/"
            "adapter-icons/qdrant.png"
        )

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def get_vector_db_instance(self) -> Optional[BasePydanticVectorStore]:
        try:
            self.collection_name = VectorDBHelper.get_collection_name(
                self.config.get(VectorDbConstants.VECTOR_DB_NAME),
                self.config.get(VectorDbConstants.EMBEDDING_DIMENSION),
            )
            url = self.config.get(Constants.URL)
            if (
                self.config.get(Constants.API_KEY) is not None
                or self.config.get(Constants.API_KEY) == ""
            ):
                self.client = QdrantClient(
                    url=url, api_key=self.config.get(Constants.API_KEY)
                )
                vector_db = QdrantVectorStore(
                    collection_name=self.collection_name,
                    client=self.client,
                    api_key=self.config.get(Constants.API_KEY),
                )
            else:
                self.client = QdrantClient(url=url)
                vector_db = QdrantVectorStore(
                    collection_name=self.collection_name, client=self.client
                )
            return vector_db
        except Exception as e:
            raise AdapterError(str(e))

    def test_connection(self) -> bool:
        vector_db = self.get_vector_db_instance()
        test_result: bool = VectorDBHelper.test_vector_db_instance(
            vector_store=vector_db
        )
        # Delete the collection that was created for testing
        if self.client is not None:
            self.client.delete_collection(self.collection_name)
        return test_result



import logging
import os
from typing import Any, Optional

import requests
from requests import Response
from requests.exceptions import ConnectionError, RequestException

from unstract.adapters.exceptions import AdapterError
from unstract.adapters.utils import AdapterUtils
from unstract.adapters.x2text.constants import X2TextConstants
from unstract.adapters.x2text.llm_whisperer.src.constants import (
    HTTPMethod,
    OutputModes,
    ProcessingModes,
    WhispererConfig,
    WhispererDefaults,
    WhispererEndpoint,
    WhispererHeader,
)
from unstract.adapters.x2text.x2text_adapter import X2TextAdapter

logger = logging.getLogger(__name__)


class LLMWhisperer(X2TextAdapter):
    def __init__(self, settings: dict[str, Any]):
        super().__init__("LLMWhisperer")
        self.config = settings

    @staticmethod
    def get_id() -> str:
        return "llmwhisperer|0a1647f0-f65f-410d-843b-3d979c78350e"

    @staticmethod
    def get_name() -> str:
        return "LLMWhisperer"

    @staticmethod
    def get_description() -> str:
        return "LLMWhisperer X2Text"

    @staticmethod
    def get_icon() -> str:
        return "/icons/" "adapter-icons/LLMWhisperer.png"

    @staticmethod
    def get_json_schema() -> str:
        f = open(f"{os.path.dirname(__file__)}/static/json_schema.json")
        schema = f.read()
        f.close()
        return schema

    def _make_request(
        self,
        request_method: HTTPMethod,
        request_endpoint: str,
        params: Optional[dict[str, Any]] = None,
        files: Optional[dict[Any, Any]] = None,
    ) -> Response:
        llm_whisperer_svc_url = (
            f"{self.config.get(WhispererConfig.URL)}" f"/v1/{request_endpoint}"
        )
        # Required when whisperer service is run locally
        platform_service_api_key = self.config.get(
            X2TextConstants.PLATFORM_SERVICE_API_KEY
        )

        headers = {
            "accept": "application/json",
            "Authorization": f"Bearer {platform_service_api_key}",
            WhispererHeader.UNSTRACT_KEY: self.config.get(
                WhispererConfig.UNSTRACT_KEY
            ),
        }

        data = None
        if files is not None:
            f = files["file"]
            data = f.read()
            headers["Content-Type"] = "application/octet-stream"

        try:
            response: Response
            if request_method == HTTPMethod.GET:
                response = requests.get(
                    url=llm_whisperer_svc_url, headers=headers  # type: ignore
                )
            elif request_method == HTTPMethod.POST:
                response = requests.post(
                    url=llm_whisperer_svc_url,
                    headers=headers,  # type: ignore
                    params=params,
                    data=data,
                )
            else:
                raise AdapterError(
                    f"Unsupported request method: {request_method}"
                )
            response.raise_for_status()
        except ConnectionError as e:
            logger.error(f"Adapter error: {e}")
            raise AdapterError(
                "Unable to connect to LLM Whisperer service, "
                "please check the URL"
            )
        except RequestException as e:
            logger.error(f"Adapter error: {e}")
            default_err = "Error while calling the LLM Whisperer service"
            msg = AdapterUtils.get_msg_from_request_exc(
                err=e, message_key="message", default_err=default_err
            )
            raise AdapterError(msg)
        return response

    def process(
        self,
        input_file_path: str,
        output_file_path: Optional[str] = None,
        **kwargs: dict[Any, Any],
    ) -> str:
        try:
            input_f = open(input_file_path, "rb")
            files = {"file": input_f}

            params = {
                WhispererConfig.PROCESSING_MODE: self.config.get(
                    WhispererConfig.PROCESSING_MODE, ProcessingModes.TEXT.value
                ),
                WhispererConfig.OUTPUT_MODE: self.config.get(
                    WhispererConfig.OUTPUT_MODE, OutputModes.LINE_PRINTER.value
                ),
                WhispererConfig.FORCE_TEXT_PROCESSING: self.config.get(
                    WhispererConfig.FORCE_TEXT_PROCESSING,
                    WhispererDefaults.FORCE_TEXT_PROCESSING,
                ),
            }
            if not params[WhispererConfig.FORCE_TEXT_PROCESSING]:
                params.update(
                    {
                        WhispererConfig.MEDIAN_FILTER_SIZE: self.config.get(
                            WhispererConfig.MEDIAN_FILTER_SIZE,
                            WhispererDefaults.MEDIAN_FILTER_SIZE,
                        ),
                        WhispererConfig.GAUSSIAN_BLUR_RADIUS: self.config.get(
                            WhispererConfig.GAUSSIAN_BLUR_RADIUS,
                            WhispererDefaults.GAUSSIAN_BLUR_RADIUS,
                        ),
                    }
                )

            response = self._make_request(
                request_method=HTTPMethod.POST,
                request_endpoint=WhispererEndpoint.WHISPER,
                params=params,
                files=files,
            )
            if response.ok and response.content is not None:
                if isinstance(response.content, bytes):
                    output = response.content.decode("utf-8")
                if output_file_path is not None:
                    with open(output_file_path, "w", encoding="utf-8") as f:
                        f.write(output)
                        f.close()
                return output
            return ""
        except AdapterError:
            raise
        # TODO: Review this practice and remove if unnecessary
        except Exception as e:
            logger.error(f"Error occured while processing document: {e}")
            raise AdapterError(str(e))
        finally:
            if input_f is not None:
                input_f.close()

    def test_connection(self) -> bool:
        self._make_request(
            request_method=HTTPMethod.GET,
            request_endpoint=WhispererEndpoint.TEST_CONNECTION,
        )
        return True
